#!/bin/bash

# I want my default user to be nobody.  you should be able to configure it to be any user (including root)
USER_NAME=${USER_NAME:-nobody}
USER_UID=${USER_UID}
USER_GID=${USER_GID}

COMMAND="$@"

# Check to see if we have been passed in a user name other than "root".  If we have, create it
#  if it does not exist and then switch to it.
if [[ -n "${USER_NAME}" && "${USER_NAME}" != "root" ]]; then
    (getent passwd ${USER_NAME} > /dev/null) || USER_DOESNT_EXIST=1

    # If the user does not exist, create it now.
    if [[ ${USER_DOESNT_EXIST} ]]; then
        if [ -n "${USER_UID}" ]; then
            UID_STR="--uid ${USER_UID}"
        fi
        if [ -n "${USER_GID}" ]; then
            # Fail silently if this already exists
            groupadd -f -g ${USER_GID} "${USER_NAME}_g" 2>/dev/null
            GID_STR="--gid ${USER_GID}"
        fi
        # Create and set correct permissions on the temp home folder
        useradd --shell /bin/bash ${UID_STR} ${GID_STR} --non-unique --comment "" -M ${USER_NAME}
    fi

    # Our working directory is "/root".  I am going to cheat a bit here and set the home
    #  directory for the user we are about o become to root.  Then we change the ownership
    #  of everything to this user. (I don't want to chown /root/.conan/data since this is
    #  mount point..)
    usermod -d $(pwd) ${USER_NAME} >/dev/null 2>&1

elif [ -z "${USER_NAME}" ]; then
    USER_NAME=root
fi

if [ -e "/var/run/docker.sock" ]; then
    DOCKER_GID=$(stat -c "%g" /var/run/docker.sock)
    OLD_GROUP=$(getent group ${DOCKER_GID} | cut -d ':' -f 1)
    if [[ $OLD_GROUP -ne 0 ]]; then
        if [[ -n "$OLD_GROUP" && "$OLD_GROUP" != "docker_g" ]]; then
            echo "*** docker group id ${DOCKER_GID} is already taken by $OLD_GROUP"
            echo "*** change docker group id on the host system to resolve"
            echo "*** do this ya lazy:"
            echo "### https://unix.stackexchange.com/questions/33844/change-gid-of-a-specific-group"
        fi
    fi
fi

echo -e "export JAVA_HOME=/usr/local/jdk-11.0.1\nexport PATH=\$JAVA_HOME/bin:\$PATH\n" > /etc/profile.d/jdk11.sh
cat /etc/profile.d/jdk11.sh
source /etc/profile.d/jdk11.sh
env | egrep '^JAVA_HOME=|^PATH='

if [ -n "${K8S_CONTEXT}" ]; then
    if [ -n "$JENKINS_URL" ]; then
        URL="-url $JENKINS_URL"
    fi

    if [ -n "$JENKINS_NAME" ]; then
        JENKINS_AGENT_NAME="$JENKINS_NAME"
    fi

    if [ "$JENKINS_WEB_SOCKET" = true ]; then
        WEB_SOCKET=-webSocket
    fi

    if [ -n "$JENKINS_SECRET" ]; then
        SECRET="-secret ${JENKINS_SECRET}"
    fi

    if [ -n "$JENKINS_AGENT_NAME" ]; then
        AGENT_NAME="-name ${JENKINS_AGENT_NAME}"
    fi

    if [ "$JENKINS_JAVA_OPTS" ]; then
        JAVA_OPTIONS="$JENKINS_JAVA_OPTS"
    else
    # if JAVA_OPTS is defined, use it
        if [ "$JAVA_OPTS" ]; then
            JAVA_OPTIONS="$JAVA_OPTS"
        fi
    fi

    # download agent.jar 
    curl -O "${JENKINS_URL}/jnlpJars/agent.jar"
    sleep 2
    java $JAVA_OPTIONS -jar agent.jar $SECRET $AGENT_NAME $URL $WEB_SOCKET
fi
